package com.ruoyi.system.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.PosStore;
import com.ruoyi.system.domain.PosType;

/**
 * 门店分类Service接口
 *
 * @author ruoyi
 * @date 2023-05-13
 */
public interface IPosTypeService extends IService<PosType>
{
    /**
     * 查询门店分类
     *
     * @param id 门店分类主键
     * @return 门店分类
     */
    public PosType selectPosTypeById(Long id);

    /**
     * 查询门店分类列表
     *
     * @param posType 门店分类
     * @return 门店分类集合
     */
    public List<PosType> selectPosTypeList(PosType posType);

    /**
     * 新增门店分类
     *
     * @param posType 门店分类
     * @return 结果
     */
    public int insertPosType(PosType posType);

    /**
     * 修改门店分类
     *
     * @param posType 门店分类
     * @return 结果
     */
    public int updatePosType(PosType posType);

    /**
     * 批量删除门店分类
     *
     * @param ids 需要删除的门店分类主键集合
     * @return 结果
     */
    public int deletePosTypeByIds(Long[] ids);

    /**
     * 删除门店分类信息
     *
     * @param id 门店分类主键
     * @return 结果
     */
    public int deletePosTypeById(Long id);

    /**
     * 查询门店分类树结构
     *
     * @param posType 门店分类
     * @return 门店分类集合
     */
    public List<PosType> selectPosTypeTreeList(PosType posType);

    /**
     * 查询子分类数量
     *
     * @param parentId 父分类ID
     * @return 结果
     */
    public int selectPosTypeCountByParentId(Long parentId);
}
